pub struct BackendConfig { /* private fields */ }Expand description
Configuration passed to every backend on creation.
Implementations
Sourceimpl BackendConfig
impl BackendConfig
Sourcepub fn queue_depth(&self) -> usize
pub fn queue_depth(&self) -> usize
Maximum number of descriptors that can be registered with the backend.
Sourcepub fn event_batch_size(&self) -> usize
pub fn event_batch_size(&self) -> usize
Number of events a backend should attempt to process per poll call.
Sourcepub fn spin_before_park(&self) -> Duration
pub fn spin_before_park(&self) -> Duration
Duration the backend may spin prior to parking the thread.
Sourcepub fn default_timeout(&self) -> Option<Duration>
pub fn default_timeout(&self) -> Option<Duration>
Default timeout applied when callers pass None to Backend::poll.
Sourcepub fn with_queue_depth(self, queue_depth: usize) -> Self
pub fn with_queue_depth(self, queue_depth: usize) -> Self
Overrides the queue depth.
Sourcepub fn with_event_batch_size(self, batch: usize) -> Self
pub fn with_event_batch_size(self, batch: usize) -> Self
Overrides the event batch size.
Sourcepub fn with_spin_before_park(self, duration: Duration) -> Self
pub fn with_spin_before_park(self, duration: Duration) -> Self
Overrides the spin duration.
Sourcepub fn with_default_timeout(self, timeout: Option<Duration>) -> Self
pub fn with_default_timeout(self, timeout: Option<Duration>) -> Self
Overrides the default timeout value.